pub struct AssistantMessage {
pub content: String,
pub name: Option<String>,
pub tool_calls: Vec<ToolCall>,
}Fields
content: StringThe contents of the system message.
name: Option<String>An optional name for the participant. Provides the model information to differentiate between participants of the same role.
tool_calls: Vec<ToolCall>The tool calls generated by the model, such as function calls